@@ -81,6 +81,8 @@
 
 ;;; Keyword functions
 
+;; ECL doesn't allow FOR clauses after UNTIL.
+#-ecl
 (defun remove-keyword (key arglist)
   (loop for sublist = arglist then rest until (null sublist)
         for (elt arg . rest) = sublist
